@@ -31,22 +31,12 @@ G_BEGIN_DECLS
 #define PANEL_HORIZONTAL_MASK (PANEL_ORIENTATION_TOP  | PANEL_ORIENTATION_BOTTOM)
 #define PANEL_VERTICAL_MASK   (PANEL_ORIENTATION_LEFT | PANEL_ORIENTATION_RIGHT)
 
-typedef enum {
-	PANEL_STATE_NORMAL       = 0,
-	PANEL_STATE_AUTO_HIDDEN  = 1,
-	PANEL_STATE_HIDDEN_UP    = 2,
-	PANEL_STATE_HIDDEN_DOWN  = 3,
-	PANEL_STATE_HIDDEN_LEFT  = 4,
-	PANEL_STATE_HIDDEN_RIGHT = 5
-} PanelState;
-
 typedef enum {
 	PANEL_OBJECT_MENU,
 	PANEL_OBJECT_LAUNCHER,
 	PANEL_OBJECT_APPLET,
 	PANEL_OBJECT_ACTION,
 	PANEL_OBJECT_MENU_BAR,
-	PANEL_OBJECT_SEPARATOR,
 	PANEL_OBJECT_USER_MENU
 } PanelObjectType;
 
